<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\User;
use App\Services\TwilioService;
use Laravel\Passport\Passport;

class AuthController extends Controller
{
    protected $twilio;

    public function __construct(TwilioService $twilio)
    {
        $this->twilio = $twilio;
    }

    public function sendOtp(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'phone_number' => 'required|string|max:15',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => $validator->errors(),
            ], 422);
        }

        try {
            $phoneNumber = $request->phone_number;
            $otp = rand(100000, 999999);

            $user = User::where('phone_number', $phoneNumber)->first();

            if (!$user) {
                $user = User::create([
                    'phone_number' => $phoneNumber,
                    'otp' => $otp,
                ]);
            } else {
                $user->otp = $otp;
                $user->save();
            }

            $this->twilio->sendOtp($phoneNumber, $otp);

            return response()->json([
                'success' => true,
                'message' => 'OTP sent successfully',
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => $e->getMessage(),
            ], 500);
        }
    }

    public function verifyOtp(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'phone_number' => 'required|string|max:15',
            'otp' => 'required|string|max:6',
            'device_token' => 'string',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => $validator->errors(),
            ], 422);
        }

        try {
            $phoneNumber = $request->phone_number;
            $otp = $request->otp;
            $deviceToken = $request->device_token;

            $user = User::where('phone_number', $phoneNumber)->where('otp', $otp)->first();

            if ($user) {
                $user->otp = null;

                $user->device_token = $deviceToken;
                $user->save();

                $token = $user->createToken('Permanent Token')->plainTextToken;

                return response()->json([
                    'success' => true,
                    'message' => 'OTP verified successfully',
                    'token' => $token,
                ], 200);
            } else {
                return response()->json([
                    'success' => false,
                    'message' => 'Invalid OTP',
                ], 400);
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => $e->getMessage(),
            ], 500);
        }
    }

}
