<?php

namespace App\Http\Controllers;

use App\Models\Notification;
use App\Models\DeliveryNotification;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class NotificationController extends Controller
{
    public function getUserNotifications()
    {
        $user = Auth::user();

        if (!$user) {
            return response()->json(['success' => false, 'message' => 'User not authenticated'], 401);
        }

        // Get all notifications ordered by created_at
        $notifications = Notification::where('user_id', $user->id)
            ->orderBy('created_at', 'desc')
            ->get()
            ->groupBy(function($notification) {
                // Group by the date only (not including time)
                return $notification->created_at->format('Y-m-d');
            });

        // Prepare an array where each day has its notifications
        $formattedNotifications = [];

        foreach ($notifications as $date => $dailyNotifications) {
            $formattedNotifications[] = [
                'date' => $date,
                'notifications' => $dailyNotifications,
            ];
        }

        return response()->json(['success' => true, 'notifications' => $formattedNotifications]);
    }
    
    public function getDeliveryNotifications()
    {
        $delivery = Auth::user();

        if (!$delivery) {
            return response()->json(['success' => false, 'message' => 'User not authenticated'], 401);
        }

        // Get all notifications ordered by created_at
        $notifications = DeliveryNotification::where('delivery_id', $delivery->id)
            ->orderBy('created_at', 'desc')
            ->get()
            ->groupBy(function($notification) {
                // Group by the date only (not including time)
                return $notification->created_at->format('Y-m-d');
            });

        // Prepare an array where each day has its notifications
        $formattedNotifications = [];

        foreach ($notifications as $date => $dailyNotifications) {
            $formattedNotifications[] = [
                'date' => $date,
                'notifications' => $dailyNotifications,
            ];
        }

        return response()->json(['success' => true, 'notifications' => $formattedNotifications]);
    }


    public function markAsRead($id)
    {
        $notification = Notification::where('user_id', auth()->id())->where('id', $id)->firstOrFail();

        if (!$notification->read_at) {
            $notification->update(['is_read' => 1]);
        }

        return response()->json(['success' => true, 'message' => 'Notification marked as read']);
    }
    
    public function markDeliveryAsRead($id)
    {
        $notification = DeliveryNotification::where('delivery_id', auth()->id())->where('id', $id)->firstOrFail();

        if (!$notification->read_at) {
            $notification->update(['is_read' => 1]);
        }

        return response()->json(['success' => true, 'message' => 'Notification marked as read']);
    }

}
