<?php

namespace App\Http\Controllers;

use App\Models\ServiceCategory;
use Illuminate\Http\Request;

class ServiceCategoryController extends Controller
{
    public function index()
    {
        $categories = ServiceCategory::with('services')->get();
        return response()->json(['success' => true, 'categories' => $categories]);
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'laundry_id' => 'required|exists:laundries,id',
            'name' => 'required|string|max:255',
        ]);

        $category = ServiceCategory::create($validated);
        return response()->json(['success' => true, 'category' => $category]);
    }

    public function show($id)
    {
        $category = ServiceCategory::with('services')->findOrFail($id);
        return response()->json(['success' => true, 'category' => $category]);
    }

    public function update(Request $request, $id)
    {
        $category = ServiceCategory::findOrFail($id);
        $validated = $request->validate([
            'name' => 'sometimes|required|string|max:255',
        ]);

        $category->update($validated);
        return response()->json(['success' => true, 'category' => $category]);
    }

    public function destroy($id)
    {
        $category = ServiceCategory::findOrFail($id);
        $category->delete();
        return response()->json(['success' => true, 'message' => 'Category deleted']);
    }
}
