<?php

namespace App\Http\Controllers;

use App\Models\Laundry;
use App\Models\Service;
use App\Models\ServiceCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ServiceController extends Controller
{
    public function listServices($laundry_id)
    {
        $services = Service::where('laundry_id', $laundry_id)->get();
        return response()->json(['success' => true, 'services' => $services]);
    }

    public function addService(Request $request, $laundry_id)
    {
        $request->validate([
            'category_name' => 'required|string|max:255',
            'service_name' => 'required|string|max:255',
            'price' => 'required|numeric|min:0',
            'is_urgent' => 'boolean',
            'details' => 'nullable|string',
        ]);

        $category = ServiceCategory::firstOrCreate([
            'laundry_id' => $laundry_id,
            'name' => $request->category_name
        ]);

        $service = $category->services()->create([
            'name' => $request->service_name,
            'price' => $request->price,
            'is_urgent' => $request->is_urgent ?? false,
            'details' => $request->details,
        ]);

        return response()->json(['success' => true, 'service' => $service]);
    }

    public function getServices($laundry_id)
    {
        $categories = ServiceCategory::with('services')
            ->where('laundry_id', $laundry_id)
            ->get();

        return response()->json(['success' => true, 'categories' => $categories]);
    }

    public function updateService(Request $request, $id)
    {
        $service = Service::findOrFail($id);

        $request->validate([
            'name' => 'sometimes|required|string|max:255',
            'price' => 'sometimes|required|numeric|min:0',
            'is_urgent' => 'boolean',
            'details' => 'nullable|string',
        ]);

        $service->update($request->all());

        return response()->json(['success' => true, 'service' => $service]);
    }

    public function deleteService($id)
    {
        $service = Service::findOrFail($id);
        $service->delete();

        return response()->json(['success' => true, 'message' => 'Service deleted successfully.']);
    }

}
