<?php

use App\Http\Controllers\AboutUsController;
use App\Http\Controllers\AddressController;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\DeliveryController;
use App\Http\Controllers\LaundryController;
use App\Http\Controllers\NotificationController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\ServiceCategoryController;
use App\Http\Controllers\ServiceController;
use App\Http\Controllers\SupportContactController;
use App\Http\Controllers\TermsConditionController;
use App\Http\Controllers\UserController;
use Illuminate\Support\Facades\Route;

Route::post('send-otp', [AuthController::class, 'sendOtp']);
Route::post('verify-otp', [AuthController::class, 'verifyOtp']);
Route::get('gel-all-users', [UserController::class, 'getAllUsers']);

Route::post('delivery/register', [DeliveryController::class, 'register']);
Route::post('delivery/login', [DeliveryController::class, 'login']);
Route::get('deliveries', [DeliveryController::class, 'getAllDeliveries']);

Route::get('about-us', [AboutUsController::class, 'show']);
Route::get('terms_conditions', [TermsConditionController::class, 'show']);
Route::get('support-contacts', [SupportContactController::class, 'index']);

Route::middleware('check.sanctum.token')->group(function () {
    Route::post('logout', [UserController::class, 'logout']);
    Route::get('user-profile', [UserController::class, 'userProfile']);
    Route::post('update-profile', [UserController::class, 'updateProfile']);

    Route::apiResource('laundries', LaundryController::class);

    Route::apiResource('service-categories', ServiceCategoryController::class);

    Route::post('orders', [OrderController::class, 'createOrder']);
    Route::get('orders', [OrderController::class, 'getUserOrders']);
    Route::get('order/{id}', [OrderController::class, 'showOrderDetails']);
    Route::post('orders/{orderId}/mark-in-progress', [OrderController::class, 'markInProgress']);
    Route::post('orders/{orderId}/mark-ready', [OrderController::class, 'markReady']);
    Route::post('orders/{orderId}/choose-pickup-type', [OrderController::class, 'choosePickupType']);
    Route::post('orders/{orderId}/mark-on-delivery', [OrderController::class, 'markOnDelivery']);
    Route::post('orders/{orderId}/mark-completed', [OrderController::class, 'markCompleted']);
    Route::post('orders/{orderId}/cancel', [OrderController::class, 'cancelOrder']);
    Route::post('orders/{orderId}/request-delivery', [OrderController::class, 'requestDelivery']);
    Route::post('orders/{orderId}/delivery-response', [DeliveryController::class, 'respondToRequest']);

    Route::get('notifications', [NotificationController::class, 'getUserNotifications']);
    Route::post('notifications/{id}/read', [NotificationController::class, 'markAsRead']);
    
    Route::get('delivery/notifications', [NotificationController::class, 'getDeliveryNotifications']);
    Route::post('delivery/notifications/{id}/read', [NotificationController::class, 'markDeliveryAsRead']);

    Route::get('laundries/{id}/services', [ServiceController::class, 'getServices']);
    Route::post('laundries/{id}/services', [ServiceController::class, 'addService']);
    Route::post('services/{id}', [ServiceController::class, 'updateService']);
    Route::delete('services/{id}', [ServiceController::class, 'deleteService']);

    Route::get('addresses', [AddressController::class, 'index']);
    Route::post('addresses', [AddressController::class, 'store']);
    Route::post('addresses/{id}', [AddressController::class, 'update']);
    Route::delete('addresses/{id}', [AddressController::class, 'destroy']);

    Route::post('terms_conditions', [TermsConditionController::class, 'update']);

    Route::post('support-contacts', [SupportContactController::class, 'store']);

    Route::post('about-us', [AboutUsController::class, 'update']);

    Route::get('delivery/profile', [DeliveryController::class, 'profile']);
    Route::post('delivery/logout', [DeliveryController::class, 'logout']);
    Route::post('delivery/update-location', [DeliveryController::class, 'updateLocation']);
    Route::post('delivery/find-nearest', [DeliveryController::class, 'findNearestDelivery']);

    Route::get('deliveries/orders', [DeliveryController::class, 'getOrdersByStatus']);
});
